==> genometools-1.3.8.tar.gz: genometools-1.3.8/src/gth/pgl_collection.h <==
/*
  Copyright (c) 2003-2010 Gordon Gremme <gremme@zbh.uni-hamburg.de>
  Copyright (c) 2003-2009 Center for Bioinformatics, University of Hamburg

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#ifndef PGL_COLLECTION_H
#define PGL_COLLECTION_H

#include "gth/gthoutput.h"
#include "gth/sa_collection.h"
#include "gth/pgl.h"
#include "gth/pgl_visitor.h"

typedef struct GthPGLCollection GthPGLCollection;

GthPGLCollection* gth_pgl_collection_new(GthSACollection*,
                                         bool disableclustersas);
void              gth_pgl_collection_delete(GthPGLCollection*);
/* Sort the alternative gene structures (AGSs) in <pgl_collection> according to
   weight factor <sortagswf>. */
void              gth_pgl_collection_sortAGSs(GthPGLCollection*,
                                              double sortagswf);
/* Set the maximum number of AGSs (<maxagsnum>) which are allowed per PGL. */
void              gth_pgl_collection_set_max_ags(GthPGLCollection*,
                                                 unsigned int maxagsnum);
/* Returns the number of consensus spliced alignments in <pgl_collection>. */
unsigned long     gth_pgl_collection_size(const GthPGLCollection*);
void              gth_pgl_collection_traverse(const GthPGLCollection*,
                                              GthPGLVisitor*, GthInput*,
                                              bool use_desc_ranges);

#endif

==> genometools_1.5.2.orig.tar.gz: genometools-1.5.2/src/gth/pgl_collection.h <==
/*
  Copyright (c) 2003-2010 Gordon Gremme <gordon@gremme.org>
  Copyright (c) 2003-2009 Center for Bioinformatics, University of Hamburg

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#ifndef PGL_COLLECTION_H
#define PGL_COLLECTION_H

#include "gth/gthoutput.h"
#include "gth/sa_collection.h"
#include "gth/pgl.h"
#include "gth/pgl_visitor.h"

typedef struct GthPGLCollection GthPGLCollection;

GthPGLCollection* gth_pgl_collection_new(GthSACollection*,
                                         bool disableclustersas);
void              gth_pgl_collection_delete(GthPGLCollection*);
/* Sort the alternative gene structures (AGSs) in <pgl_collection> according to
   weight factor <sortagswf>. */
void              gth_pgl_collection_sortAGSs(GthPGLCollection*,
                                              double sortagswf);
/* Set the maximum number of AGSs (<maxagsnum>) which are allowed per PGL. */
void              gth_pgl_collection_set_max_ags(GthPGLCollection*,
                                                 unsigned int maxagsnum);
/* Returns the number of consensus spliced alignments in <pgl_collection>. */
GtUword     gth_pgl_collection_size(const GthPGLCollection*);
void              gth_pgl_collection_traverse(const GthPGLCollection*,
                                              GthPGLVisitor*, GthInput*,
                                              bool use_desc_ranges);

#endif
